@@ -1,6 +1,5 @@
 import requests
 import json
-from .visualization import Visualization
 import webbrowser
 
 
@@ -24,14 +23,11 @@ class Session(object):
         return str(self.id)
 
     def __repr__(self):
+        s = "Session\n"
+        s += "number: " + str(self.id)
         if self.name:
-            return "Session number: " + str(self.id) + ", name: " + self.name
-        return "Session number: " + str(self.id)
-
-    def create_visualization(self, data=None, images=None, type=None):
-        viz = Visualization.create(session=self, data=data, images=images, type=type)
-        self.visualizations.append(viz)
-        return viz
+            s += "name: " + str(self.name)
+        return s
 
     def open(self):
         webbrowser.open(self.host + '/sessions/' + str(self.id) + '/feed/')
@@ -45,6 +41,5 @@ class Session(object):
             payload = {'name': name}
 
         headers = {'Content-type': 'application/json', 'Accept': 'text/plain'}
-
         r = requests.post(url, data=json.dumps(payload), headers=headers, auth=lgn.auth)
         return cls(lgn=lgn, json=r.json())
