@@ -626,4 +626,17 @@ class Histogram(Base):
         outdict = {'values': values}
         outdict = add_property(outdict, bins, 'bins')
 
-        return outdict
\ No newline at end of file
+        return outdict
+
+
+@viztype
+class VegaLite(Base):
+
+    _name = 'vega-lite'
+    _func = 'vega_lite'
+
+    @staticmethod
+    def clean(spec):
+        outdict = {}
+        outdict = add_property(outdict, spec, 'spec')
+        return outdict
